=== modified file 'NEWS'
--- NEWS	2009-06-02 00:09:55 +0000
+++ NEWS	2009-05-16 06:16:33 +0000
@@ -4,8 +4,6 @@
 dev [future]
 ---------------
 
-    - Add bug links in revision informations (Alexandre Garnier, #314052)
-
     - Make sure that binary files aren't annotated. (Martin Albisetti,
       #258848)
 
@@ -115,14 +113,6 @@
     - Fix annotating non-UTF-8 files when Pygments is disabled. (Matt
       Nordhoff, #376957)
 
-    - Fix 'bzr serve --http' errors. (Matt Nordhoff, #377551)
-
-    - Fix serving branches over HTTP. (Matt Nordhoff, Jelmer Vernooij,
-      #380026)
-
-    - Support serving branches over HTTP using the smart server protocol. 
-      (Jelmer Vernooij, #306853)
-
 1.10 [22Dec2008]
 ---------------
 

=== modified file '__init__.py'
--- __init__.py	2009-05-27 07:23:03 +0000
+++ __init__.py	2009-05-06 18:48:16 +0000
@@ -38,72 +38,51 @@
 
     require_any_api(bzrlib, [(1, 11, 0), (1, 13, 0), (1, 15, 0)])
 
+    # TODO: This should provide a new type of server that can be used by bzr
+    # serve, maybe through a registry, rather than overriding the command.  Though
+    # maybe we should keep the wrapper to work with older bzr releases, at least
+    # for a bit.
+
     # NB: Normally plugins should lazily load almost everything, but this
     # seems reasonable to have in-line here: bzrlib.commands and options are
     # normally loaded, and the rest of loggerhead won't be loaded until serve
     # --http is run.
         
-    # transport_server_registry was added in bzr 1.16. When we drop support for
-    # older releases, we can remove the code to override cmd_serve.
-
-    try:
-        from bzrlib.transport import transport_server_registry
-    except ImportError:
-        transport_server_registry = None
-
-    DEFAULT_HOST = '0.0.0.0'
+    import bzrlib.builtins
+    from bzrlib.commands import get_cmd_object, register_command
+    from bzrlib.option import Option
+
+    _original_command = get_cmd_object('serve')
+
     DEFAULT_PORT = 8080
-    HELP = ('Loggerhead web-based code viewer and server. (default port: %d)' %
-            (DEFAULT_PORT,))
-
-    def serve_http(transport, host=None, port=None, inet=None):
-        # loggerhead internal code will try to 'import loggerhead', so
-        # let's put it on the path
-        import os.path, sys
-        sys.path.append(os.path.dirname(__file__))
-
-        from loggerhead.apps.transport import BranchesFromTransportRoot
-        from loggerhead.config import LoggerheadConfig
-        from paste.httpexceptions import HTTPExceptionHandler
-        from paste.httpserver import serve
-        if host is None:
-            host = DEFAULT_HOST
-        if port is None:
-            port = DEFAULT_PORT
-        argv = ['--host', host, '--port', str(port), transport.base]
-        config = LoggerheadConfig(argv)
-        app = BranchesFromTransportRoot(transport, config)
-        app = HTTPExceptionHandler(app)
-        serve(app, host=host, port=port)
-
-    if transport_server_registry is not None:
-        transport_server_registry.register('http', serve_http, help=HELP)
-    else:
-        import bzrlib.builtins
-        from bzrlib.commands import get_cmd_object, register_command
-        from bzrlib.option import Option
-
-        _original_command = get_cmd_object('serve')
-
-        class cmd_serve(bzrlib.builtins.cmd_serve):
-            __doc__ = _original_command.__doc__
-
-            takes_options = _original_command.takes_options + [
-                Option('http', help=HELP)]
-
-            def run(self, *args, **kw):
-                if 'http' in kw:
-                    from bzrlib.transport import get_transport
-                    path = kw.get('directory', '.')
-                    port = kw.get('port', DEFAULT_PORT)
-                    # port might be an int already...
-                    if isinstance(port, basestring) and ':' in port:
-                        host, port = port.split(':')
-                    else:
-                        host = DEFAULT_HOST
-                    transport = get_transport(path)
-                    serve_http(transport, host, port)
+
+    class cmd_serve(bzrlib.builtins.cmd_serve):
+        __doc__ = _original_command.__doc__
+
+        takes_options = _original_command.takes_options + [
+            Option('http',
+                help='Run an http (Loggerhead) server to browse code, '
+                    'by default on port %s.' % DEFAULT_PORT)]
+
+        def run(self, *args, **kw):
+            if 'http' in kw:
+                # loggerhead internal code will try to 'import loggerhead', so
+                # let's put it on the path
+                import os.path, sys
+                sys.path.append(os.path.dirname(__file__))
+
+                from loggerhead.apps.transport import BranchesFromTransportRoot
+                from paste.httpexceptions import HTTPExceptionHandler
+                from paste.httpserver import serve
+                a = HTTPExceptionHandler(BranchesFromTransportRoot('.'))
+                port = kw.get('port', DEFAULT_PORT)
+                # port might be an int already...
+                if isinstance(port, basestring) and ':' in port:
+                    host, port = port.split(':')
                 else:
-                    super(cmd_serve, self).run(*args, **kw)
+                    host = '0.0.0.0'
+                serve(a, host=host, port=port)
+            else:
+                super(cmd_serve, self).run(*args, **kw)
 
-        register_command(cmd_serve)
+    register_command(cmd_serve)

=== modified file 'loggerhead/apps/branch.py'
--- loggerhead/apps/branch.py	2009-05-27 16:21:06 +0000
+++ loggerhead/apps/branch.py	2009-05-13 11:34:09 +0000
@@ -123,12 +123,7 @@
             if public_branch is not None:
                 self.served_url = public_branch
             else:
-                # Loggerhead only supports serving .bzr/ on local branches, so
-                # we shouldn't suggest something that won't work.
-                if self.branch.base.startswith('file://'):
-                    self.served_url = self.url([])
-                else:
-                    self.served_url = None
+                self.served_url = self.url([])
         path = request.path_info_pop(environ)
         if not path:
             raise httpexceptions.HTTPMovedPermanently(

=== modified file 'loggerhead/apps/transport.py'
--- loggerhead/apps/transport.py	2009-06-02 00:09:55 +0000
+++ loggerhead/apps/transport.py	2009-05-04 20:28:50 +0000
@@ -1,8 +1,6 @@
 """Serve branches at urls that mimic a transport's file system layout."""
 
 from bzrlib import branch, errors, lru_cache, urlutils
-from bzrlib.transport import get_transport
-from bzrlib.transport.http import wsgi
 
 from paste.request import path_info_pop
 from paste import httpexceptions
@@ -83,22 +81,9 @@
             return static_app(environ, start_response)
         elif environ['PATH_INFO'] == '/favicon.ico':
             return favicon_app(environ, start_response)
-        elif environ['PATH_INFO'].endswith("/.bzr/smart"):
-            # Only do readonly for now
-            transport = get_transport("readonly+" + self.transport.base)
-            wsgi_app = wsgi.SmartWSGIApp(self.transport)
-            wsgi_app = wsgi.RelpathSetter(wsgi_app, '', 'PATH_INFO')
-            return wsgi_app(environ, start_response)
         elif '/.bzr/' in environ['PATH_INFO']:
-            # TODO: Use something here that uses the transport API 
-            # rather than relying on the local filesystem API.
-            try:
-                path = urlutils.local_path_from_url(self.transport.base)
-            except errors.InvalidURL:
-                raise httpexceptions.HTTPNotFound()
-            else:
-                app = urlparser.make_static(None, path)
-                return app(environ, start_response)
+            app = urlparser.make_static(None, self.transport)
+            return app(environ, start_response)
         else:
             return BranchesFromTransportServer(
                 self.transport, self)(environ, start_response)

=== modified file 'loggerhead/config.py'
--- loggerhead/config.py	2009-05-18 05:16:38 +0000
+++ loggerhead/config.py	2009-04-16 22:28:17 +0000
@@ -55,11 +55,9 @@
 class LoggerheadConfig(object):
     '''A configuration object.'''
 
-    def __init__(self, argv=None):
-        if argv is None:
-            argv = sys.argv[1:]
+    def __init__(self):
         self._parser = command_line_parser()
-        self._options, self._args = self._parser.parse_args(argv)
+        self._options, self._args = self._parser.parse_args(sys.argv[1:])
 
         sql_dir = self.get_option('sql_dir')
         if sql_dir is None:

=== modified file 'loggerhead/controllers/directory_ui.py'
--- loggerhead/controllers/directory_ui.py	2009-05-28 13:56:43 +0000
+++ loggerhead/controllers/directory_ui.py	2009-05-05 18:37:26 +0000
@@ -20,7 +20,7 @@
 import logging
 import stat
 
-from bzrlib import branch, errors
+from bzrlib import branch
 
 from loggerhead import util
 from loggerhead.controllers import TemplatedBranchView
@@ -73,10 +73,7 @@
             try:
                 b = branch.Branch.open_from_transport(self.transport.clone(d))
             except:
-                try:
-                    if not stat.S_ISDIR(self.transport.stat(d).st_mode):
-                        continue
-                except errors.NoSuchFile:
+                if not stat.S_ISDIR(self.transport.stat(d).st_mode):
                     continue
                 b = None
             dirs.append(DirEntry(d, parity, b))

=== modified file 'loggerhead/history.py'
--- loggerhead/history.py	2009-05-28 22:48:45 +0000
+++ loggerhead/history.py	2009-04-24 10:30:15 +0000
@@ -31,9 +31,13 @@
 import bisect
 import datetime
 import logging
+import marshal
 import re
 import textwrap
 import threading
+import time
+import urllib
+from StringIO import StringIO
 
 from loggerhead import search
 from loggerhead import util
@@ -232,6 +236,9 @@
         parents of this revision.
     :ivar _rev_indices: A dictionary mapping each revision id to the index of
         the information about it in _rev_info.
+    :ivar _full_history: A list of all revision ids in the ancestry of the
+        branch, in merge-sorted order.  This is a bit silly, and shouldn't
+        really be stored on the instance...
     :ivar _revno_revid: A dictionary mapping stringified revnos to revision
         ids.
     """
@@ -264,15 +271,19 @@
             update_missed_caches()
 
         if self._rev_indices is not None:
+            self._full_history = []
             self._revno_revid = {}
             for ((_, revid, _, revno_str, _), _, _) in self._rev_info:
                 self._revno_revid[revno_str] = revid
+                self._full_history.append(revid)
         else:
+            self._full_history = []
             self._revno_revid = {}
             self._rev_indices = {}
             for ((seq, revid, _, revno_str, _), _, _) in self._rev_info:
                 self._rev_indices[revid] = seq
                 self._revno_revid[revno_str] = revid
+                self._full_history.append(revid)
 
     def __init__(self, branch, whole_history_data_cache, file_cache=None,
                  revinfo_disk_cache=None, cache_key=None):
@@ -316,7 +327,7 @@
         revid in revid_list.
         """
         if revid_list is None:
-            revid_list = [r[0][1] for r in self._rev_info]
+            revid_list = self._full_history
         revid_set = set(revid_list)
         revid = start_revid
 
@@ -348,9 +359,9 @@
             w = self._branch.repository.weave_store.get_weave(
                     file_id, self._branch.repository.get_transaction())
             w_revids = w.versions()
-            revids = [r for r in self._rev_indices if r in w_revids]
+            revids = [r for r in self._full_history if r in w_revids]
         except AttributeError:
-            possible_keys = [(file_id, revid) for revid in self._rev_indices]
+            possible_keys = [(file_id, revid) for revid in self._full_history]
             get_parent_map = self._branch.repository.texts.get_parent_map
             # We chunk the requests as this works better with GraphIndex.
             # See _filter_revisions_touching_file_id in bzrlib/log.py
@@ -681,7 +692,6 @@
             'comment': revision.message,
             'comment_clean': [util.html_clean(s) for s in message],
             'parents': revision.parent_ids,
-            'bugs': [bug.split()[0] for bug in revision.properties.get('bugs', '').splitlines()],
         }
         return util.Container(entry)
 

=== modified file 'loggerhead/static/css/diff.css'
--- loggerhead/static/css/diff.css	2009-05-30 17:40:05 +0000
+++ loggerhead/static/css/diff.css	2009-02-26 20:55:46 +0000
@@ -31,7 +31,7 @@
     width:493px;
     margin:0px 0px 5px 0px;
 }
-.information, .committer, .timer, .mfrom, .mto, .revid, .bug {
+.information, .committer, .timer, .mfrom, .mto, .revid {
     clear:both;
     margin:0px;
     padding:0px 0px 2px 18px;
@@ -65,14 +65,6 @@
 .mto {
     background:url(../images/ico_mergeto.gif) no-repeat top left;
 }
-.bug {
-    padding:1px 0px 0px 18px;
-    margin:0px 10px 5px 0px;
-    float:left;
-    clear:none;
-    display:inline;
-    background:url(../images/ico_bug.png) no-repeat top left;
-}
 /**/
 #loggerheadCont p.expand, #loggerheadCont p.expand a, #loggerheadCont p.expand a:link, #loggerheadCont p.expand a:visited, #loggerheadCont p.expand a:hover {
     color:#0f6b97;

=== modified file 'loggerhead/static/css/files.css'
--- loggerhead/static/css/files.css	2009-05-28 22:48:45 +0000
+++ loggerhead/static/css/files.css	2009-01-23 20:53:40 +0000
@@ -1,5 +1,5 @@
 /*Info Box*/
-.information, .committer, .timer, .mfrom, .mto, .revid, .bug {
+.information, .committer, .timer, .mfrom, .mto, .revid {
 	float:left;
 	margin:0px 10px 5px 0px;
 	padding:0px 0px 2px 18px;
@@ -39,6 +39,3 @@
     width:100%;
     position:relative;
 }
-.bug {
-	background:url(../images/ico_bug.png) no-repeat top left;
-}

=== removed file 'loggerhead/static/images/ico_bug.png'
Binary files loggerhead/static/images/ico_bug.png and loggerhead/static/images/ico_bug.png differ
=== modified file 'loggerhead/templates/revisioninfo.pt'
--- loggerhead/templates/revisioninfo.pt	2009-05-30 17:40:05 +0000
+++ loggerhead/templates/revisioninfo.pt	2009-04-28 03:01:54 +0000
@@ -18,10 +18,6 @@
             <tal:b content="merged_in"/></a>.
         </div>
         <div class="revid" tal:content="string:Revision ID: ${change/revid}"></div>
-        <div class="clear"><!-- --></div>
-        <div class="bug" tal:repeat="bug change/bugs">
-            <a tal:attributes="href bug" tal:content="bug"></a>
-        </div>
         <div class="information" tal:content="structure python:util.fixed_width(change.comment)"></div>
     </div>
     <ul id="list-files" tal:condition="file_changes">

=== modified file 'loggerhead/wholehistory.py'
--- loggerhead/wholehistory.py	2009-05-18 04:17:11 +0000
+++ loggerhead/wholehistory.py	2009-04-24 10:30:15 +0000
@@ -53,6 +53,7 @@
          graph.iter_ancestry([last_revid]) if value is not None))
 
     _revision_graph = _strip_NULL_ghosts(parent_map)
+    _full_history = []
 
     _rev_info = []
     _rev_indices = {}
@@ -65,6 +66,7 @@
 
     for info in _merge_sort:
         seq, revid, merge_depth, revno, end_of_merge = info
+        _full_history.append(revid)
         revno_str = '.'.join(str(n) for n in revno)
         parents = _revision_graph[revid]
         _rev_indices[revid] = len(_rev_info)

